@@ -4,7 +4,7 @@
  * GChemPaint library
  * atom.cc
  *
- * Copyright (C) 2001-2005
+ * Copyright (C) 2001-2006
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -56,6 +56,8 @@
 
 using namespace gcu;
 
+#define ATOM_EPSILON 0.1
+
 extern GtkTextTagTable* TextTagTable;
 
 gcpAtom::gcpAtom(): Atom()
@@ -138,7 +140,7 @@ void gcpAtom::SetZ(int Z)
 {
 	Atom::SetZ(Z);
 	m_Element = Element::GetElement (m_Z);
-	if (m_Valence = m_Element->GetDefaultValence ())
+	if ((m_Valence = m_Element->GetDefaultValence ()))
 		m_HPos = GetBestSide();
 	else
 		m_nH = 0;
@@ -204,18 +206,21 @@ bool gcpAtom::GetBestSide()
 	else return Element::BestSide(m_Z);
 }
 
-void gcpAtom::Update()
+void gcpAtom::Update ()
 {
-	if (m_ChargeAuto)
-	{
+	if (m_ChargeAuto) {
 		m_Charge = 0;
 		m_ChargeAuto = false;
 	}
+	if (m_ChargeAutoPos) {
+		NotifyPositionOccupation (m_ChargePos, false);
+		m_ChargePos = 0xff;
+	}
 	int nb, nexplp = 0, nexplu = 0; //nexplp is the number of explicit lone pairs
 	//nexplu is the number of explicit unpaired electrons
 	map<string, Object*>::iterator i;
 	gcpElectron* electron = (gcpElectron*) GetFirstChild (i);
-	while (electron){ 
+	while (electron) { 
 		if (electron->IsPair ())
 			nexplp++;
 		else
@@ -225,7 +230,7 @@ void gcpAtom::Update()
 	int nbonds = GetTotalBondsNumber ();
 	if (m_Valence > 0) {
 		m_nlp = (m_Element->GetValenceElectrons () - m_Valence) / 2;
-		if ((m_Charge > 0) && (m_nlp > 0)) m_nlp --;
+		if ((m_Charge > 0) && (m_nlp > 0)) m_nlp -= (m_Charge + 1) / 2;
 		else if (m_Charge < 0)
 			m_nlp -= m_Charge;
 		if (m_nlp < nexplp) // Can this occur ?
@@ -795,6 +800,9 @@ void gcpAtom::Update(GtkWidget* w)
 		if (item)
 			gtk_object_destroy (GTK_OBJECT (item));
 			g_object_set_data ((GObject*)group, "charge", NULL);
+			g_object_set_data ((GObject*)group, "figure", NULL);
+			g_object_set_data ((GObject*)group, "circle", NULL);
+			g_object_set_data ((GObject*)group, "sign", NULL);
 	}
 	map<string, Object*>::iterator i;
 	Object* electron = GetFirstChild (i);
@@ -836,14 +844,30 @@ void gcpAtom::UpdateAvailablePositions ()
 		while ((n != m_AngleList.end()) && (*n < angle)) n++;
 		m_AngleList.insert(n, angle);
 		i++;
-		if ((m_AvailPos & CHARGE_SW) && (angle >= 180.0) && (angle <= 270.0)) m_AvailPos -= CHARGE_SW;
-		if ((m_AvailPos & CHARGE_SE) && (((angle >= 270.0) && (angle <= 360.0)) || (fabs(angle) < 0.1))) m_AvailPos -= CHARGE_SE;
-		if ((m_AvailPos & CHARGE_S) && (angle >= 225.0) && (angle <= 315.0)) m_AvailPos -= CHARGE_S;
-		if ((m_AvailPos & CHARGE_NW) && (angle >= 90.0) && (angle <= 180.0)) m_AvailPos -= CHARGE_NW;
-		if ((m_AvailPos & CHARGE_NE) && (((angle >= 0.0) && (angle <= 90.0)) || (fabs(angle - 360.0) < 0.1))) m_AvailPos -= CHARGE_NE;
-		if ((m_AvailPos & CHARGE_N) && (angle >= 45.0) && (angle <= 135.0)) m_AvailPos -= CHARGE_N;
-		if ((m_AvailPos & CHARGE_W) && ((angle <= 225.0) && (angle >= 135.0))) m_AvailPos -= CHARGE_W;
-		if ((m_AvailPos & CHARGE_E) && ((angle >= 315.0) || (angle <= 45.0))) m_AvailPos -= CHARGE_E;
+		if ((m_AvailPos & CHARGE_SW) && (angle >= 180.0 - ATOM_EPSILON) &&
+			(angle <= 270.0 + ATOM_EPSILON))
+			m_AvailPos -= CHARGE_SW;
+		if ((m_AvailPos & CHARGE_SE) && (((angle >= 270.0 - ATOM_EPSILON) &&
+			(angle <= 360.0 + ATOM_EPSILON)) || (fabs(angle) < ATOM_EPSILON)))
+			m_AvailPos -= CHARGE_SE;
+		if ((m_AvailPos & CHARGE_S) && (angle >= 225.0 - ATOM_EPSILON) &&
+			(angle <= 315.0 + ATOM_EPSILON))
+			m_AvailPos -= CHARGE_S;
+		if ((m_AvailPos & CHARGE_NW) && (angle >= 90.0 - ATOM_EPSILON) &&
+			(angle <= 180.0 + ATOM_EPSILON))
+			m_AvailPos -= CHARGE_NW;
+		if ((m_AvailPos & CHARGE_NE) && (((angle >= 0.0 - ATOM_EPSILON) &&
+			(angle <= 90.0 + ATOM_EPSILON)) || (fabs(angle - 360.0) < ATOM_EPSILON)))
+			m_AvailPos -= CHARGE_NE;
+		if ((m_AvailPos & CHARGE_N) && (angle >= 45.0 - ATOM_EPSILON) &&
+			(angle <= 135.0 + ATOM_EPSILON))
+			m_AvailPos -= CHARGE_N;
+		if ((m_AvailPos & CHARGE_W) && ((angle <= 225.0 + ATOM_EPSILON) &&
+			(angle >= 135.0 - ATOM_EPSILON)))
+			m_AvailPos -= CHARGE_W;
+		if ((m_AvailPos & CHARGE_E) && ((angle >= 315.0 - ATOM_EPSILON) ||
+			(angle <= 45.0 + ATOM_EPSILON)))
+			m_AvailPos -= CHARGE_E;
 	}
 	m_AngleList.push_back ((angle = m_AngleList.front ()) + 360.0);
 	m_InterBonds.clear ();
@@ -1098,11 +1122,11 @@ void gcpAtom::SetSelected(GtkWidget* w, int state)
 	}
 	g_object_set (G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")),
 				"fill_color", color, NULL);
-	if (item = g_object_get_data(G_OBJECT(group), "figure"))
+	if ((item = g_object_get_data(G_OBJECT(group), "figure")))
 		g_object_set (item, "fill_color", chargecolor, NULL);
-	if (item = g_object_get_data(G_OBJECT(group), "circle"))
+	if ((item = g_object_get_data(G_OBJECT(group), "circle")))
 		g_object_set (item, "outline_color", chargecolor, NULL);
-	if (item = g_object_get_data(G_OBJECT(group), "sign"))
+	if ((item = g_object_get_data(G_OBJECT(group), "sign")))
 		g_object_set (item, "outline_color", chargecolor, NULL);
 	Object::SetSelected (w, state);
 }
@@ -1242,6 +1266,7 @@ void gcpAtom::BuildItems (gcpWidgetData* pData)
 			g_object_set_data (G_OBJECT (group), "symbol", NULL);
 		}
 		m_length = m_text_height = 0;
+		gnome_canvas_item_lower_to_bottom (GNOME_CANVAS_ITEM (group));
 	}
 	m_width /= pData->ZoomFactor;
 	m_height /= pData->ZoomFactor;
@@ -1523,3 +1548,31 @@ void gcpAtom::SetCharge (int charge)
 	m_ChargeAuto = false;
 	Update ();
 }
+
+void gcpAtom::Transform2D (Matrix2D& m, double x, double y)
+{
+	Atom::Transform2D (m, x, y);
+	// Now transform electrons
+	map<string, Object*>::iterator i;
+	Object* electron = GetFirstChild (i);
+	while (electron) {
+		electron->Transform2D (m, x, y);
+		electron = GetNextChild (i);
+	}
+	if (GetCharge ()) {
+		m_ChargeAutoPos = false; // should be fixed before 0.6.4
+/*		if (m_ChargeAutoPos) {
+			if (m_ChargePos > 0)
+				NotifyPositionOccupation (m_ChargePos, false);
+			m_ChargePos = 0xff;
+			Update ();
+		} else {*/
+			double xc = cos (m_ChargeAngle), yc = - sin (m_ChargeAngle);
+			m.Transform (xc, yc);
+			m_ChargeAngle = atan2 (- yc, xc);
+			if (m_ChargeAngle < 0)
+				m_ChargeAngle += 2 * M_PI;
+			SetChargePosition (0, FALSE, m_ChargeAngle, m_ChargeDist);
+//		}
+	}
+}
