@@ -4,7 +4,7 @@
  * GChemPaint library
  * mesomery.h 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -31,6 +31,8 @@
 
 using namespace gcu;
 
+class gcpMesomer;
+
 class gcpMesomery: public Object
 {
 public:
@@ -38,11 +40,17 @@ public:
 	virtual ~gcpMesomery ();
 	
 	virtual void Add (GtkWidget* w);
-	virtual xmlNodePtr Save (xmlDocPtr xml);
 	virtual bool Load (xmlNodePtr);
 	virtual bool Build (list<Object*>& Children) throw (invalid_argument);
+	virtual void Transform2D (Matrix2D& m, double x, double y);
+	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
+	virtual bool OnSignal (SignalId Signal, Object *Child);
 	bool Validate (bool split);
 	void Align ();
+	virtual double GetYAlign ();
+
+private:
+	gcpMesomery (Object* parent, gcpMesomer *mesomer);
 };
 
 #endif	//GCHEMPAINT_MESOMERY_H
