@@ -46,7 +46,7 @@ void gcpPlugin::LoadPlugins ()
 	GDir* dir = g_dir_open (LIBDIR"/gchempaint/plugins", 0, NULL);
 	if (dir ==  NULL) return;
 	const char* name;
-	while (name = g_dir_read_name (dir)) {
+	while ((name = g_dir_read_name (dir))) {
 		if (strcmp (name + strlen (name) - 3, ".so")) continue;
 		name = g_strconcat (LIBDIR"/gchempaint/plugins/", name, NULL);
 		if (!dlopen (name, RTLD_NOW)) puts (dlerror());
