@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -44,6 +44,7 @@ public:
 	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
 	virtual bool OnSignal (SignalId Signal, Object *Child);
 	virtual bool Load (xmlNodePtr);
+	virtual double GetYAlign ();
 };
 
 #endif	//GCHEMPAINT_REACTION_H
