@@ -56,8 +56,7 @@ gcpRetrosynthesisArrow::~gcpRetrosynthesisArrow()
 
 xmlNodePtr gcpRetrosynthesisArrow::Save (xmlDocPtr xml)
 {
-	xmlNodePtr parent, node, child;
-	gchar buf[16];
+	xmlNodePtr parent, node;
 	node = xmlNewDocNode (xml, NULL, (xmlChar*)"retrosynthesis-arrow", NULL);
 	if (!node) return NULL;
 	if (!gcpArrow::Save (xml, node)) {
@@ -201,10 +200,21 @@ void gcpRetrosynthesisArrow::SetSelected(GtkWidget* w, int state)
 	gchar* color;
 	switch (state)
 	{	
-		case SelStateUnselected: color = Color; break;
-		case SelStateSelected: color = SelectColor; break;
-		case SelStateUpdating: color = AddColor; break;
-		case SelStateErasing: color = DeleteColor; break;
+	case SelStateUnselected:
+		color = Color;
+		break;
+	case SelStateSelected:
+		color = SelectColor;
+		break;
+	case SelStateUpdating:
+		color = AddColor;
+		break;
+	case SelStateErasing:
+		color = DeleteColor;
+		break;
+	default:
+		color = Color;
+		break;
 	}
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "arrow")),
 						"outline_color", color,
