@@ -70,9 +70,9 @@ gcpTextTool::~gcpTextTool()
 
 bool gcpTextTool::OnClicked()
 {
-	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != TextType) || (m_Active != m_pData->Items[m_pObject]->item_list->data)))
-	{
-		Unselect();
+	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType () != TextType) ||
+			(m_Active != g_object_get_data (G_OBJECT (m_pData->Items[m_pObject]), "text")))) {
+		Unselect ();
 	}
 	if (!m_pObject)
 	{
@@ -211,14 +211,7 @@ bool gcpTextTool::Deactivate()
 
 bool gcpTextTool::NotifyViewChange()
 {
-	bool result = true;
-	if (m_Active)
-	{
-		result = Unselect();
-		sleep(1);
-		while(gtk_events_pending()) gtk_main_iteration();
-	}
-	return result;
+	return (m_Active)? Unselect(): true;
 }
 
 bool gcpTextTool::Unselect()
@@ -288,7 +281,6 @@ bool gcpTextTool::Unselect()
 	if (m_CurNode) xmlFree(m_CurNode);
 	if (m_InitNode) xmlFree(m_InitNode);
 	m_CurNode = m_InitNode = NULL;
-	while(gtk_events_pending()) gtk_main_iteration();
 	if (!*text)
 	{
 		Object* pMol = pObj->GetMolecule();	//if pObj is a fragment
